unit fMain;

{$mode objfpc}{$H+}

interface

uses
  MyForms,
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls,
  LCLTranslator;

type

  { TMainForm }

  TMainForm = class(TMyForm)
    SwitchLanguageButton: TButton;
    WizardButton: TButton;
    CloseButton: TButton;
    procedure CloseApplication(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure OpenWizard(Sender: TObject);
    procedure SwitchLanguage(Sender: TObject);
  private
    procedure SelectLanguage(ALang: String);
    procedure UpdateTranslation(ALang: String); override;
  public
    { public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.lfm}

uses
  fProjectWizard;


{ TMainForm
  ---------------------------------------------------------------------------- }

{$region ' FORM EVENTS '}

procedure TMainForm.FormCreate(Sender: TObject);
begin
   // Setup Language
  SelectLanguage('de');
end;


{$endregion}


{$region ' PRIVATE SECTION '}

procedure TMainForm.SelectLanguage(ALang: String);
var
  i, p: Integer;
  lang: String;
begin
  { This is the main procedure that has to be called when changing language:
    - It replaces resourcestrings with the translated ones.
    - It activates the format settings corresponding to the new language
    - It tries to use the BiDi mode for the new language (not completely correct)
    - It calls "UpdateTranslation" for itself and for each form of the project -
      this way, the forms can do things that are not done automatically.
    - It updates the language selector combobox }


  // Switch language - this is in LCLTranslator
  SetDefaultLang(ALang);

  // Switch default settings by calling the procedure provided in SonicForms.pas.
  UpdateFormatSettings(ALang);

  // Adjust BiDiMode to new language
  UpdateBiDiMode(ALang);

  // Update items not automatically translated.
  UpdateTranslation(ALang);

  // Select the new language in the language combobox.
  (*
  ALang := lowercase(ALang);
  for i:=0 to CbLanguage.Items.Count-1 do begin
    lang := CbLanguage.Items[i];
    p := pos(' ', lang);
    if p = 0 then p := pos('-', lang);
    if p = 0 then
      raise Exception.Create('Language items are not properly formatted.');
    lang := lowercase(copy(lang, 1, p-1));
    if lang = ALang then begin
      CbLanguage.ItemIndex := i;
      break;
    end;
  end;
  *)

  { Remember the new language. Forms may want to check in UpdateTranslation
    whether the new language has a different BiDiMode. }
  CurrentLang := ALang;
end;

procedure TMainForm.UpdateTranslation(ALang: String);
begin
  inherited UpdateTranslation(ALang);
end;

{$endregion}


{$region ' EVENTS '}

procedure TMainForm.CloseApplication(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.OpenWizard(Sender: TObject);
begin
  TProjectWizard.ShowWizard;
end;

procedure TMainForm.SwitchLanguage(Sender: TObject);
begin
  if (CurrentLang = 'de') or (CurrentLang = EmptyStr)
  then SelectLanguage('en')
  else SelectLanguage('de');
end;

{$endregion}


end.

