unit MyWizards;

{$mode objfpc}{$H+}

interface

uses
  MyForms, Classes, SysUtils, FileUtil, Forms, Controls, Graphics,
  Dialogs, StdCtrls, ComCtrls, ExtCtrls;

type

  { TMyWizard }

  TMyWizard = class(TMyForm)
    CancelButton: TButton;
    BackButton: TButton;
    StartTitleLabel: TLabel;
    ReadTitleLabel: TLabel;
    ErrorTitleLabel: TLabel;
    SuccessTitleLabel: TLabel;
    NavigationPanel: TPanel;
    NextButton: TButton;
    PageControl: TPageControl;
    ReadySheet: TTabSheet;
    StartSheet: TTabSheet;
    ErrorSheet: TTabSheet;
    SuccessSheet: TTabSheet;
    procedure GoBack(Sender: TObject);
    procedure GoNext(Sender: TObject);
  private
    procedure Execute;
    procedure UpdateNavigationControls;
  protected
    procedure UpdateTranslation(ALang: String); override;
  public
    { public declarations }
  end;


implementation

{$R *.lfm}

const
  Tag_StartSheet   = 'StartSheet';
  Tag_ReadySheet   = 'ReadySheet';
  Tag_SuccessSheet = 'SuccessSheet';
  Tag_ErrorSheet   = 'ErrorSheet';

resourcestring
  Tag_Back   = '%Zurück';
  Tag_Next   = '&Weiter';
  Tag_Finish = '&Fertigstellen';
  Tag_Close  = '&Beenden';
  Tag_Cancel = '&Abbrechen';



{ TMyWizard
  ---------------------------------------------------------------------------- }

{$region ' PRIVATE SECTION '}

procedure TMyWizard.Execute;
begin
  // do nothing now
end;

procedure TMyWizard.UpdateNavigationControls;
begin
  with PageControl do
  begin
    // Back Button
    if (ActivePage.Name = Tag_StartSheet) or
       (ActivePage.Name = Tag_ErrorSheet) or
       (ActivePage.Name = Tag_SuccessSheet)
    then BackButton.Enabled := false
    else BackButton.Enabled := true;


    // Next Button
    if (ActivePage.Name = Tag_ReadySheet) or
       (ActivePage.Name = Tag_ErrorSheet) or
       (ActivePage.Name = Tag_SuccessSheet)
    then NextButton.Caption := Tag_Finish
    else NextButton.Caption := Tag_Next;

    if (ActivePage.Name = Tag_ErrorSheet) or
       (ActivePage.Name = Tag_SuccessSheet)
    then NextButton.Enabled := false
    else NextButton.Enabled := true;


    // Cancel Button
    if (ActivePage.Name = Tag_ErrorSheet) or
       (ActivePage.Name = Tag_SuccessSheet)
    then CancelButton.Caption := Tag_Close
    else CancelButton.Caption := Tag_Cancel;
  end;
end;

{$endregion}


{$region ' PROTECTED SECTION - i18n '}

procedure TMyWizard.UpdateTranslation(ALang: String);
begin
  inherited UpdateTranslation(ALang);
end;

{$endregion}


{$region ' EVENTS '}

procedure TMyWizard.GoBack(Sender: TObject);
begin
  // Go one Sheet back
  if (PageControl.ActivePageIndex > 0)
  then PageControl.SelectNextPage(false);
end;

procedure TMyWizard.GoNext(Sender: TObject);
begin
  if (NextButton.Caption = Tag_Next) then
  begin
    // Go one Sheet foreward
    PageControl.SelectNextPage(true);
  end else

  if (NextButton.Caption = Tag_Finish) then
  begin
    // Execute Wizard Functionality
    Execute;
  end;
end;

end.

